# HtDP in Python

## English

This is an educational library inspired by the _htdp_ library existing for the Racket language, aiming to enable the use of ideas similar to the _How to Design Programs_ approach for teaching programming. _How to Design Programs_ is a textbook developed by Matthias Felleisen, Robert Bruce Findler, Matthew Flatt and Shriram Krishnamurthi, and presents an interesting approach on teaching program design. The book can be accessed in https://htdp.org/2018-01-06/Book/index.html

The library's implementation is based on Pygame and facilitates de development of games and interactive programs by means of an interesting API which is easy to learn.

This is the Portuguese version of the API

## Portuguese

Esta é uma biblioteca de fins educacionais inspirada pela biblioteca _htdp_ existente na linguagem Racket, visando permitir o uso de ideias similares à abordagem _How to Design Programs_ para o ensino de programação. _How to Design Programs_ é um livro-texto desenvolvido por Matthias Felleisen, Robert Bruce Findler, Matthew Flatt e Shriram Krishnamurth, e apresenta uma abordagem interessante para o ensino de projeto (_design_) de programas. O livro pode ser acessado em https://htdp.org/2018-01-06/Book/index.html

A implementação da biblioteca é baseada em Pygame e facilita o desenvolvimento de jogos e programas interativos por meio de uma interessante API que é fácil de aprender.

Está é a versão em Português da API.  